@@ -1452,9 +1452,8 @@ UnixMakefileGenerator::writeLibtoolFile()
 
     TQTextStream t(&ft);
     t << "# " << lname << " - a libtool library file\n";
-    time_t now = time(NULL);
     t << "# Generated by qmake/libtool (" << qmake_version() << ") (TQt "
-      << TQT_VERSION_STR << ") on: " << ctime(&now) << "\n";
+      << TQT_VERSION_STR << ")\n";
 
     t << "# The name that we can dlopen(3).\n"
       << "dlname='" << var(project->isActiveConfig("plugin") ? "TARGET" : "TARGET_x")
