@@ -1869,7 +1869,7 @@ TQTextStream &TQTextStream::output_int( int format, unsigned long long n, bool n
     static const char hexdigits_upper[] = "0123456789ABCDEF";
     CHECK_STREAM_PRECOND
     char buf[76];
-    register char *p;
+    char *p;
     int	  len;
     const char *hexdigits;
 
@@ -2099,7 +2099,7 @@ TQTextStream &TQTextStream::operator<<( double f )
 	f_char = (flags() & uppercase) ? 'E' : 'e';
     else
 	f_char = (flags() & uppercase) ? 'G' : 'g';
-    register char *fs = format;			// generate format string
+    char *fs = format;			// generate format string
     *fs++ = '%';				//   "%.<prec>l<f_char>"
     *fs++ = '.';
     int prec = precision();
